//+------------------------------------------------------------------+
//|                                           HighBarLowBar_v01.mq4  |
//|                                Copyright  2006, Damian Gaskell. |
//|                                             damian@alsalasa.com  |
//+------------------------------------------------------------------+
// See notes section below for explanation of indicator.

#property copyright "Copyright  2006, Damian Gaskell."
#property link      "http://groups.yahoo.com/group/MetaTrader_Experts_and_Indicators/"

#property indicator_chart_window
#property indicator_buffers 4
#property indicator_color1 DodgerBlue
#property indicator_color2 OrangeRed
#property indicator_color3 Blue
#property indicator_color4 Yellow

extern int MAperiod1 = 5, MAperiod2 = 14 ;
double ExtMapBuffer0[], ExtMapBuffer1[], ExtMapBuffer2[], ExtMapBuffer3[] ;
double lstbuysig, lstsellsig;

int init()
  {
   SetIndexStyle(0,DRAW_ARROW);
   SetIndexArrow(0,225);
   SetIndexBuffer(0,ExtMapBuffer0);
   SetIndexEmptyValue(0,0.0);
   SetIndexDrawBegin(0,0);

   SetIndexStyle(1,DRAW_ARROW);
   SetIndexArrow(1,226);
   SetIndexBuffer(1,ExtMapBuffer1);
   SetIndexEmptyValue(1,0.0);
   SetIndexDrawBegin(1,0);

   SetIndexStyle(2,DRAW_LINE);
   SetIndexBuffer(2,ExtMapBuffer2);
   SetIndexEmptyValue(2,0.0);
   SetIndexDrawBegin(2,0);

   SetIndexStyle(3,DRAW_LINE);
   SetIndexBuffer(3,ExtMapBuffer3);
   SetIndexEmptyValue(3,0.0);
   SetIndexDrawBegin(3,0);

   return(0);
  }

int deinit(){
   ObjectsDeleteAll(0,EMPTY);// clear the chart on exit etc.
   return(0);
   }

int start()
  {
   if (MAperiod1>MAperiod2)
   {
   Comment("HighBarLowBar_v01 Indicator.  !! Warning, Indicator cannot work !! Please edit MAperiod1 to be shorter than MAperiod2. Or remove, then attach again with the defaults."); 
   Alert("Fast EMA ",MAperiod1," is slower than slow EMA ",MAperiod2," !! \nPlease edit MAperiod1 to be shorter than MAperiod2.\nOr remove, then attach again with the defaults."); 
   return(0);
   }
   ObjectsDeleteAll(0,EMPTY); //clear lines ready to draw fresh

   int counted_bars=IndicatorCounted();
   if (counted_bars<0) return(-1);
   if (counted_bars>0) counted_bars--;
   int pos=Bars-counted_bars;
   while(pos>=2)
   {
double mafast = iMA(0,0,MAperiod1,0,MODE_EMA,PRICE_CLOSE,pos);
double maslow = iMA(0,0,MAperiod2,0,MODE_EMA,PRICE_CLOSE,pos);

 ExtMapBuffer2[pos]= mafast;
 ExtMapBuffer3[pos]= maslow;

//if uptrend draw arrows on high of highbar Bars
 if(mafast>maslow && High[pos-1]<High[pos] &&   High[pos+1]<High[pos])
  {
   ExtMapBuffer0[pos]= High[pos];
   lstbuysig = High[pos];
   }
 else

// else if downtrend draw arrows on low of lowbar Bars 
//(have to specify downtrend or it will draw arrows on lowbars during uptrend)

 if(mafast<maslow && Low[pos-1]>Low[pos] &&   Low[pos+1]>Low[pos])
  {
   ExtMapBuffer1[pos]= Low[pos];
   lstsellsig = Low[pos];
    }
  pos--;
  }
  Comment("HighBarLowBar_v01 Indicator. MA periods: ",MAperiod1,", ",MAperiod2, "\nLast Buy Signal: ",lstbuysig,"\nLast Sell Signal: ",lstsellsig); 
  ObjectCreate("lstbuysig_line",OBJ_HLINE,0,0,lstbuysig,0,0,0,0);
  ObjectCreate("lstsellsig_line",OBJ_HLINE,0,0,lstsellsig,0,0,0,0); 
  return(0);
  }

/* ::::   Notes   :::::
  
The basic idea is to buy highbar breakouts in a uptrend and sell downbar breakouts in a downtrend.
The trend is determined with fast (default 5) and slow (default 14) EMA's.
The EMA's can be changed in indicator properties.
A highbar (buy) is when the highs of the bars on each side are lower than the high of the current bar.
The trade should be entered when the price breaks above the high the signal was generated at.
Trades should only be entered in the direction of the trend. 
The opposite applies to a lowbar (sell).

I suggest a stop loss at...
   10 - 20 pips or 
   close of signal bar or
   Slow MA

Take profit at...
   10 - 30 pips or
   MA Crossover or
   Slow MA or
   Fast MA no longer rising
    
I suspect this will be good if used with momentum (Williams %R for example) to confirm and 
to catch the momentum part of a breakout for a quick intraday trade on the 15 min chart. 
Placing a pending order ahead of the move, if it comes, should have you in a positive position quickly,
(remember to cancel it if the breakout does not happen!).
Then exit when the momentum oscillator reaches extremes or turns around.
Oh and, as always, use at your own risk!
*/



    